usage: create_cli_help.py upgrade [-h] [-u MAX_VERSION] [-p PARAMETER PARAMETER]

### options:
- `-h, --help`: show this help message and exit
- `-u MAX_VERSION, --max-version MAX_VERSION`
- `upper bound limit version`
- `-p PARAMETER PARAMETER, --parameter PARAMETER PARAMETER`
- `Assign variable for running SQL deltas. Format is: name value.`
